<template>
  <div ref="results" class="page-search-results" :class="resultClass">
    <van-cell v-if="crossStation && resResult.length > 0" class="all">
      <span class="count">当前共选择 {{ selectedCount }} 个</span>
      <van-checkbox v-model="checked" @change="handleCheckAll">全选</van-checkbox>
    </van-cell>
    <van-list v-if="resResult.length > 0">
      <van-cell v-for="item in resResult" :key="item.id" :title="item.name" @click.stop.prevent="onClickCell(item)">
        <template #icon>
          <van-image round width="40" height="40" :src="require('@/assets/images/mapSearch/驻勤点.png')" />
        </template>
        <template #label>
          <div v-if="resourceType === 'TemporarySecurity'" class="cell-label">
            <p>{{ "岗点类型：" + getStationTypesName(item.stationTypes) }}</p>
          </div>
          <div class="cell-label">
            <p>{{ resourceTypeMap[resourceType] + "地址：" + item.address }}</p>
          </div>
        </template>
        <template #extra>
          <van-checkbox v-if="crossStation" v-model="item.checked" @change="onCheck"></van-checkbox>
        </template>
      </van-cell>
      <div class="load-more">
        <van-button type="info" v-if="!finished" block @click="onLoad()" :disabled="loading"> 加载更多 </van-button>
      </div>
    </van-list>
    <van-empty v-else image="search" description="暂无数据" />
  </div>
</template>

<script>
import { mapGetters, mapState } from "vuex";
import { List, Cell, Image as VanImage, Button, Checkbox, Empty } from "vant";
import { getStations } from "@/api/security-station-controller";
import { findInArray } from "@/utils";

export default {
  name: "StationResultList",
  components: {
    [List.name]: List,
    [Cell.name]: Cell,
    [VanImage.name]: VanImage,
    [Button.name]: Button,
    [Checkbox.name]: Checkbox,
    [Empty.name]: Empty,
  },
  props: {
    resourceType: String,
    keyword: String,
    departIds: Array,
    stationTypes: Array,
    deskTypes: {
      type: Array,
      default() {
        return ["Normal", "Proprietor"];
      },
    },
  },
  data() {
    return {
      resResult: [],
      loading: false,
      finished: false,
      pageIndex: 1,
      resourceTypeMap: {
        Security: "驻勤点",
        Population: "社区警务",
        TemporarySecurity: "临保岗点",
      },
      checked: false,
      selectedCount: 0,
    };
  },
  computed: {
    ...mapGetters(["crossStation", "sysUserInfo"]),
    ...mapState({
      allStationTypes: (state) => state.app.stationTypes,
    }),
    userRole() {
      return this.sysUserInfo.role;
    },
    showTabs() {
      // return userRole !== 'Proprietor' && userRole !== 'Company' && userRole !== 'Urban' && userRole !== 'SubUrb'
      return !["Proprietor", "Company", "Urban", "SubUrb"].includes(this.userRole);
    },
    resultClass() {
      return this.crossStation
        ? `page-search-results-has-footer page-search-results-has-footer-${this.showTabs ? "show-tabs" : "no-tabs"}`
        : `page-search-results-${this.showTabs ? "show-tabs" : "no-tabs"}`;
    },
    // selectedCount() {
    //   return this.resResult.filter((x) => x.checked).length;
    // },
  },
  watch: {
    keyword: {
      handler(newV, oldV) {
        if (newV !== oldV) {
          this.initLoading();
          this.onLoad();
        }
      },
      immediate: false,
    },
    stationTypes: {
      handler() {
        this.initLoading();
        this.onLoad();
      },
      immediate: false,
      deep: true,
    },
    departIds() {
      this.initLoading();
      this.onLoad();
    },
  },
  methods: {
    initLoading() {
      this.pageIndex = 1;
      this.resResult = [];
      this.finished = false;
    },
    onLoad() {
      this.loading = true;
      console.log("on load");
      getStations({
        pageIndex: this.pageIndex,
        pageSize: 10,
        searchModel: "Name",
        stationTypes: this.stationTypes,
        keyword: this.keyword,
        resourceType: this.resourceType,
        deskTypes: this.resourceType === "TemporarySecurity" ? ["TemporarySecurity"] : ["Normal", "Proprietor"],
        superviseDepartIds: this.departIds,
      })
        .then((res) => {
          console.log(res);
          if (!res || res.length <= 0) {
            this.finished = true;
            return;
          }
          console.log(this.resResult);
          this.resResult = [...this.resResult, ...res];

          // 数据全部加载完成
          if ([...res].length <= 0) {
            this.finished = true;
            // this.pageIndex = 1;
          } else {
            this.pageIndex++;
          }

          this.$emit("search", this.resResult);
          this.onCheck();

          //   this.$store.commit("SET_STATION_LIST_LENGTH", this.resResult.length);
        })
        .catch((err) => {
          console.log(err);
        })
        .finally(() => {
          // 加载状态结束
          this.loading = false;
          if (this.resResult.length > 10) {
            this.$nextTick(() => {
              this.scrollToBottom();
            });
          }
        });
    },
    scrollToBottom() {
      const container = this.$refs.results;
      console.log(container);
      container.scrollTop = container.scrollHeight;
    },
    onClickCell(item) {
      console.log(item);
      if (!this.crossStation) {
        let path = "stationInfo";
        if (this.resourceType === "TemporarySecurity") {
          path = "tempStationInfo";
        }
        this.$router.push({
          path,
          query: {
            queryId: item.id,
            type: this.resourceType,
          },
        });
      }
    },
    onCheck() {
      const checked = this.resResult.filter((x) => x.checked);
      this.selectedCount = checked.length;
      this.$emit("select", checked);
    },
    handleCheckAll(value) {
      this.resResult.forEach((item) => (item.checked = value));
      const checked = this.resResult.filter((x) => x.checked);
      this.selectedCount = checked.length;
      this.$emit("select", value ? this.resResult : []);
      // this.$forceUpdate();
    },
    getStationTypesName(stationTypes) {
      if (!stationTypes || stationTypes.length <= 0) return "";
      if (this.allStationTypes.length <= 0) return "";
      let stationTypesName = "";
      const allStations = findInArray(this.allStationTypes, stationTypes, "code");
      if (allStations && allStations.length > 0) {
        stationTypesName = allStations.map((x) => x.name).join(",");
      }
      return stationTypesName;
    },
  },
  created() {
    this.onLoad();
  },
};
</script>

<style scoped lang="less">
.page-search-results {
  //margin-top: 2px;
  height: calc(100vh - 46px - 44px - 44px - 60px);
  overflow-y: scroll; //设置这个 才能指定高度
  background: #ffffff;

  .van-list {
    height: 100%;
  }

  &-no-tabs {
    height: calc(100vh - 46px - 44px - 44px);
  }

  &-show-tabs {
    height: calc(100vh - 46px - 44px - 44px - 44px);
  }

  &-has-footer {
    height: calc(100vh - 46px - 44px - 44px - 60px);
    &-no-tabs {
      height: calc(100vh - 46px - 44px - 44px - 50px - 44px);
    }
  }

  .load-more {
    height: 60px;
    padding: 10px;
  }

  .all {
    .van-cell__value {
      display: flex;
      align-items: center;
      justify-content: space-between;
    }
  }
  .per-name {
    height: 40px;
    width: 40px;
    background: #0e71ff;
    color: #fff;
    font-size: 12px;
    display: flex;
    align-items: center;
    justify-content: center;
  }
  .cell-label {
    display: flex;
    justify-content: space-between;
    flex-wrap: wrap;
    p {
      width: 100%;
      margin: 0;
      display: flex;
      align-items: center;
      .icon {
        width: 16px;
        height: 16px;
        display: inline-block;
        margin-right: 2px;
        &-mobile {
          background: url("~@/assets/images/mapSearch/电话.png") no-repeat;
          background-size: 100% 100%;
        }
        &-id {
          background: url("~@/assets/images/mapSearch/身份.png") no-repeat;
          background-size: 100% 100%;
        }
      }
    }
    span {
      display: flex;
      align-items: center;
      //justify-content: space-between;
      .icon {
        width: 16px;
        height: 16px;
        display: inline-block;
        margin-right: 2px;
        &-mobile {
          background: url("~@/assets/images/mapSearch/电话.png") no-repeat;
          background-size: 100% 100%;
        }
        &-id {
          background: url("~@/assets/images/mapSearch/身份.png") no-repeat;
          background-size: 100% 100%;
        }
      }
    }
  }
}
</style>
